summaryrefslogtreecommitdiff
path: root/Source/Core/DiscIO/VolumeVerifier.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'Source/Core/DiscIO/VolumeVerifier.cpp')
-rw-r--r--Source/Core/DiscIO/VolumeVerifier.cpp7
1 files changed, 4 insertions, 3 deletions
diff --git a/Source/Core/DiscIO/VolumeVerifier.cpp b/Source/Core/DiscIO/VolumeVerifier.cpp
index c0a33372db..1dd112c295 100644
--- a/Source/Core/DiscIO/VolumeVerifier.cpp
+++ b/Source/Core/DiscIO/VolumeVerifier.cpp
@@ -549,10 +549,11 @@ bool VolumeVerifier::CheckPartition(const Partition& partition)
}
}
// The loop above ends without breaking for discs that legitimately lack updates.
// No such discs have been released to end users. Most such discs are debug signed,
// but there is apparently at least one that is retail signed, the Movie-Ch Install Disc.
- return false;
+ if (!invalid_disc_header)
+ return false;
}
if (invalid_disc_header)
{
@@ -549,10 +549,11 @@ bool VolumeVerifier::CheckPartition(const Partition& partition)
}
}
- // The loop above ends without breaking for discs that legitimately lack updates.
- // No such discs have been released to end users. Most such discs are debug signed,
+ // The loop above ends without setting invalid_disc_header for discs that legitimately lack
+ // updates. No such discs have been released to end users. Most such discs are debug signed,
// but there is apparently at least one that is retail signed, the Movie-Ch Install Disc.